@@ -168,8 +168,7 @@ class WSGIResponse(object):
         try:
             first_iteration = output.next()
         except StopIteration:
-            first_interation = ""
-        
+            first_iteration = ""
         if self.headers_sent:
             raise AssertionError("start_response was not called")
         
