@@ -1,8 +1,8 @@
 from dez.network import SocketClient, SocketDaemon, Connection
 import sys
 
-def main(port):
-    server = SocketDaemon("localhost", port, cb=TestCloseChunked)
+def main(**kwargs):
+    server = SocketDaemon(kwargs['domain'], kwargs['port'], cb=TestCloseChunked)
     server.start()
 
 
